## stdf tamer
This package was originally developed at DC Jona / ams-OSRAM.

It is a general purpose stdf file parser / generator / simulator / analyser and converter.

But mainly it is used for these use cases.:

 - write STDF files from robotframework test cases
 - analyse STDF file content
 - convert STDF files to other file formats

Source.:
https://gittf.ams-osram.info/labor-rapperswil-jona/ams-tamer
